@@ -69,10 +69,10 @@ def CreateSession(self, destination, args):
     '''
 
     if 'Target' not in args or args['Target'].upper() != 'PBAP':
-        raise dbus.exceptions.DBusException(OBEX_MOCK_IFACE + '.Unsupported',
-                                            'Non-PBAP targets are not ' +
-                                            'currently supported by this ' +
-                                            'python-dbusmock template.')
+        raise dbus.exceptions.DBusException(
+            'Non-PBAP targets are not currently supported by this ' +
+            'python-dbusmock template.',
+            name=OBEX_MOCK_IFACE + '.Unsupported')
 
     # Find the first unused session ID.
     client_path = '/org/bluez/obex/client'
