@@ -38,7 +38,8 @@ def load(mock, parameters):
 
     mock.AddMethods(MAIN_IFACE, [
         ('GetCapabilities', '', 'as', 'ret = %s' % repr(caps)),
-        ('CloseNotification', 'i', '', 'if args[0] < self.next_id: self.EmitSignal("", "NotificationClosed", "uu", [args[0], 1])'),
+        ('CloseNotification', 'i', '', 'if args[0] < self.next_id: self.EmitSignal('
+                                       '"", "NotificationClosed", "uu", [args[0], 1])'),
         ('GetServerInformation', '', 'ssss', 'ret = ("mock-notify", "test vendor", "1.0", "1.1")'),
         ('Notify', 'susssasa{sv}i', 'u', '''if args[1]:
     ret = args[1]
